@@ -17,10 +17,10 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GSPELL_LANGUAGE_CHOOSER_H__
-#define __GSPELL_LANGUAGE_CHOOSER_H__
+#ifndef GSPELL_LANGUAGE_CHOOSER_H
+#define GSPELL_LANGUAGE_CHOOSER_H
 
-#if !defined (__GSPELL_H_INSIDE__) && !defined (GSPELL_COMPILATION)
+#if !defined (GSPELL_H_INSIDE) && !defined (GSPELL_COMPILATION)
 #error "Only <gspell/gspell.h> can be included directly."
 #endif
 
@@ -38,21 +38,28 @@ struct _GspellLanguageChooserInterface
 {
 	GTypeInterface parent_interface;
 
-	const GspellLanguage *	(* get_language)	(GspellLanguageChooser *chooser);
+	/* The return value is the same as get_language(), but there is the
+	 * (optional) out parameter @default_language in addition.
+	 */
+	const GspellLanguage *	(* get_language_full)	(GspellLanguageChooser *chooser,
+							 gboolean              *default_language);
 
 	void			(* set_language)	(GspellLanguageChooser *chooser,
 							 const GspellLanguage  *language);
-
-	gpointer padding[8];
 };
 
-const GspellLanguage *	gspell_language_chooser_get_language	(GspellLanguageChooser *chooser);
+const GspellLanguage *	gspell_language_chooser_get_language		(GspellLanguageChooser *chooser);
 
-void			gspell_language_chooser_set_language	(GspellLanguageChooser *chooser,
-								 const GspellLanguage  *language);
+void			gspell_language_chooser_set_language		(GspellLanguageChooser *chooser,
+									 const GspellLanguage  *language);
+
+const gchar *		gspell_language_chooser_get_language_code	(GspellLanguageChooser *chooser);
+
+void			gspell_language_chooser_set_language_code	(GspellLanguageChooser *chooser,
+									 const gchar           *language_code);
 
 G_END_DECLS
 
-#endif /* __GSPELL_LANGUAGE_CHOOSER_H__ */
+#endif /* GSPELL_LANGUAGE_CHOOSER_H */
 
 /* ex:set ts=8 noet: */
